@@ -14,13 +14,16 @@ from django.db.models import Field, TextField
 from django.utils.translation import gettext_lazy as _
 
 from .forms import JSONFormField, EditorMdFormField
-from .helper import get_kelove_databases_settings
+from .helper import get_kelove_databases_settings, json_value_to_python
 
 
 class JSONField(Field):
     """
     JSON 字段
     """
+
+    empty_strings_allowed = False
+
     description = _("JSON")
 
     default_error_messages = {
@@ -51,27 +54,20 @@ class JSONField(Field):
         if value in self.empty_values:
             return {}
 
-        if isinstance(value, dict) or isinstance(value, list):
-            return value
-
-        if isinstance(value, tuple) or isinstance(value, set):
-            return list(value)
-
-        if isinstance(value, str):
-            try:
-                return json.loads(value)
-            except json.JSONDecodeError:
-                raise ValidationError(
-                    self.error_messages['json_decode_error'],
-                    code='invalid',
-                    params={'value': value},
-                )
-
-        raise ValidationError(
-            self.error_messages['invalid_nullable' if self.null else 'invalid'],
-            code='invalid',
-            params={'value': value},
-        )
+        try:
+            return json_value_to_python(value)
+        except json.JSONDecodeError:
+            raise ValidationError(
+                self.error_messages['json_decode_error'],
+                code='invalid',
+                params={'value': value},
+            )
+        except ValueError:
+            raise ValidationError(
+                self.error_messages['invalid_nullable' if self.null else 'invalid'],
+                code='invalid',
+                params={'value': value},
+            )
 
     def get_prep_value(self, value):
         value = super().get_prep_value(value)
@@ -79,10 +75,13 @@ class JSONField(Field):
             return None
         return json.dumps(self.to_python(value))
 
+    def value_from_object(self, obj):
+        return self.to_python(super().value_from_object(obj))
+
 
 class EditorMdField(TextField):
     """
-
+    Markdown 编辑器字段
     """
     description = _("Editor Md")
 
