@@ -6,10 +6,11 @@
 #       修改时间: 
 #       copyright (c) 2016 - 2020 mail@xqitw.cn
 # ==================================================================
-
+import json
 from importlib import import_module
 
 from django.conf import settings
+from django.utils.translation import gettext_lazy as _
 
 STATUS_CHOICES: list = [(-1, '草稿'), (0, '待审'), (1, '通过'), (2, '驳回')]
 
@@ -217,3 +218,22 @@ def get_kelove_databases_settings(key: str = None, default=None):
         return kelove_databases_settings
     else:
         return kelove_databases_settings.get(key, default)
+
+
+def json_value_to_python(value):
+    """
+    格式化json数据
+    :param value:
+    :return:
+    """
+
+    if isinstance(value, dict) or isinstance(value, list):
+        return value
+
+    if isinstance(value, tuple) or isinstance(value, set):
+        return list(value)
+
+    if isinstance(value, str):
+        return json.loads(value)
+
+    raise ValueError(_('Invalid json value "%s"') % str(value))
