@@ -106,7 +106,7 @@ class StatusModel(Model):
     status = models.IntegerField(
         verbose_name=_('status'),
         null=False,
-        default=0,
+        default=1,
         choices=STATUS_CHOICES,
         help_text=_('status') + dumps(dict(STATUS_CHOICES), ensure_ascii=False)
     )
@@ -123,7 +123,7 @@ class EnabledModel(Model):
     # 是否启用
     enabled = models.BooleanField(
         verbose_name=_('enabled'),
-        default=False,
+        default=True,
         db_index=True,
     )
 
